Welcome to Cim2BusBranch’s documentation! — Cim2BusBranch v0.1 documentation

### Navigation

- index
- next |
- Cim2BusBranch v0.1 documentation »

# Welcome to Cim2BusBranch’s documentation!

Contents:

- Getting Started
  - Installation
  - Basic Usage
- On power grid topology representations
- Working with the bus/branch topology
  - Attributes of `Bus`
- Transforming from CIM to bus/branch
- API documentation

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- Cim2BusBranch v0.1 documentation »